@@ -6,7 +6,7 @@ from typing import Optional, Iterator, Union, List
 from requests import sessions, Response
 
 from ballchasing.constants import GroupSortBy, SortDir, AnyPlaylist, AnyMap, AnySeason, AnyRank, AnyReplaySortBy, \
-    AnySortDir, AnyVisibility, AnyGroupSortBy, AnyPlayerIdentification, AnyTeamIdentification
+    AnySortDir, AnyVisibility, AnyGroupSortBy, AnyPlayerIdentification, AnyTeamIdentification, AnyMatchResult
 from .util import rfc3339, replay_cols, team_cols, player_cols, parse_replay
 
 DEFAULT_URL = "https://ballchasing.com/api"
@@ -58,8 +58,18 @@ class Api:
         """
         headers = {"Authorization": self.auth_key}
         url = f"{self.base_url}{url_or_endpoint}" if url_or_endpoint.startswith("/") else url_or_endpoint
+        retries = 0
         while True:
-            r = method(url, headers=headers, **params)
+            try:
+                r = method(url, headers=headers, **params)
+                retries = 0
+            except ConnectionError as e:
+                print("Connection error, trying again in 10 seconds...")
+                time.sleep(10)
+                retries += 1
+                if retries >= 10:
+                    raise e
+                continue
             if 200 <= r.status_code < 300:
                 return r
             elif r.status_code == 429:
@@ -92,7 +102,7 @@ class Api:
                     player_id: Optional[Union[str, List[str]]] = None,
                     playlist: Optional[Union[AnyPlaylist, List[AnyPlaylist]]] = None,
                     season: Optional[Union[AnySeason, List[AnySeason]]] = None,
-                    match_result: Optional[Union[str, List[str]]] = None,
+                    match_result: Optional[Union[AnyMatchResult, List[AnyMatchResult]]] = None,
                     min_rank: Optional[AnyRank] = None,
                     max_rank: Optional[AnyRank] = None,
                     pro: Optional[bool] = None,
